Subject: [PATCH] gnu: Fix some typos in the installer.
From: Tobias Geerinckx-Rice <[email-masked]>
To: [email-masked]
Date: Sun, 10 Feb 2019 15:59:32 +0100
List-Id: <debbugs-submit.debbugs.gnu.org>

* gnu/installer/connman.scm (connman-connect-with-auth): Fix typo in
docstring.
* gnu/installer/newt/keymap.scm (sort-variants): Likewise.
* gnu/installer/newt/page.scm (run-listbox-selection-page): Likewise.
* gnu/installer/parted.scm (mkpart): Likewise.
* gnu/installer/newt/utils.scm (destroy-form-and-pop): Likewise.
* gnu/installer/newt/timezone.scm (timezone-listbox-heigth): Rename to…
(timezone-listbox-height): …this.
* gnu/installer/newt/wifi.scm (run-unknown-error-page): Fix typo.
(wifi-listbox-heigth): Rename to…
(wifi-listbox-height): …this, and adjust caller.
---

Hullo,

Some minor typo fixes, mainly in docstrings, one user-visible.

TIMEZONE-LISTBOX-HEIGTH appears unused, so perhaps it can just go?

Kind regards,

T G-R

 gnu/installer/connman.scm       | 2 +-
 gnu/installer/newt/keymap.scm   | 2 +-
 gnu/installer/newt/page.scm     | 2 +-
 gnu/installer/newt/timezone.scm | 4 ++--
 gnu/installer/newt/utils.scm    | 2 +-
 gnu/installer/newt/wifi.scm     | 8 ++++----
 gnu/installer/parted.scm        | 4 ++--
 7 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/gnu/installer/connman.scm b/gnu/installer/connman.scm
index 740df7424a..ef8cca3952 100644
--- a/gnu/installer/connman.scm
+++ b/gnu/installer/connman.scm
@@ -299,7 +299,7 @@ to merge stdout and stderr using bash redirection. Then error messages are
 extracted from connmanctl output using a regexp. This makes the whole
 procedure even more unreliable.
 
-Raise &connman-connection-error if an error occured during connection. Raise
+Raise &connman-connection-error if an error occurred during connection. Raise
 &connman-password-error if the given password is incorrect."
 
   (define connman-error-regexp (make-regexp "Error[ ]*([^\n]+)\n"))
diff --git a/gnu/installer/newt/keymap.scm b/gnu/installer/newt/keymap.scm
index 6211af2bc5..3e765bfdd4 100644
--- a/gnu/installer/newt/keymap.scm
+++ b/gnu/installer/newt/keymap.scm
@@ -71,7 +71,7 @@
     (cut append <> <>)))
 
 (define (sort-variants variants)
-  "Sort VARIANTS list by putting the internation variant ahead and return it."
+  "Sort VARIANTS list by putting the international variant ahead and return it."
   (call-with-values
       (lambda ()
         (partition
diff --git a/gnu/installer/newt/page.scm b/gnu/installer/newt/page.scm
index edf0b8c999..23fbfcce76 100644
--- a/gnu/installer/newt/page.scm
+++ b/gnu/installer/newt/page.scm
@@ -188,7 +188,7 @@ If SORT-LISTBOX-ITEMS? is set to #t, the listbox items are sorted using
 'string<=' procedure (after being converted to text).
 
 If ALLOW-DELETE? is #t, the form will return if the <DELETE> key is pressed,
-otherwise nothing will happend.
+otherwise nothing will happen.
 
 Each time the listbox current item changes, call SKIP-ITEM-PROCEDURE? with the
 current listbox item as argument. If it returns #t, skip the element and jump
diff --git a/gnu/installer/newt/utils.scm b/gnu/installer/newt/utils.scm
index 1c2ce4e628..dfb113e0c6 100644
--- a/gnu/installer/newt/utils.scm
+++ b/gnu/installer/newt/utils.scm
@@ -30,7 +30,7 @@
 (define screen-rows    (make-parameter 0))
 
 (define (destroy-form-and-pop form)
-  "Destory the given FORM and pop the current window."
+  "Destroy the given FORM and pop the current window."
   (destroy-form form)
   (pop-window))
 
diff --git a/gnu/installer/parted.scm b/gnu/installer/parted.scm
index 187311e633..020f77086f 100644
--- a/gnu/installer/parted.scm
+++ b/gnu/installer/parted.scm
@@ -677,7 +677,7 @@ otherwise."
 (define* (mkpart disk user-partition
                  #:key (previous-partition #f))
   "Create the given USER-PARTITION on DISK. The PREVIOUS-PARTITION argument as
-to be set to the partition preceeding USER-PARTITION if any."
+to be set to the partition preceding USER-PARTITION if any."
 
   (define (parse-start-end start end)
     "Parse start and end strings as positions on DEVICE expressed with a unit,
@@ -735,7 +735,7 @@ cause them to cross."
                                (+ start-sector start-offset)
                                start-sector)))
        ;; This is a hackery but parted almost always fails to create optimally
-       ;; aligned partitions (unless specifiying percentages) because, the
+       ;; aligned partitions (unless specifying percentages) because, the
        ;; default range of 1MB centered on the start sector is not enough when
        ;; the optimal alignment is 2048 sectors of 512KB.
        (extend-ranges! start-range end-range #:offset start-offset)
diff --git a/gnu/installer/newt/timezone.scm b/gnu/installer/newt/timezone.scm
index 6c96ee55b1..80583f638b 100644
--- a/gnu/installer/newt/timezone.scm
+++ b/gnu/installer/newt/timezone.scm
@@ -30,8 +30,8 @@
   #:use-module (newt)
   #:export (run-timezone-page))
 
-;; Heigth of the listbox displaying timezones.
-(define timezone-listbox-heigth (make-parameter 20))
+;; Height of the listbox displaying timezones.
+(define timezone-listbox-height (make-parameter 20))
 
 ;; Information textbox width.
 (define info-textbox-width (make-parameter 40))
diff --git a/gnu/installer/newt/wifi.scm b/gnu/installer/newt/wifi.scm
index 59e40e327e..4cf5c128e7 100644
--- a/gnu/installer/newt/wifi.scm
+++ b/gnu/installer/newt/wifi.scm
@@ -100,7 +100,7 @@ nmc_wifi_strength_bars."
   "Run a page to inform user that a connection error happened."
   (run-error-page
    (format #f
-           (G_ "An error occured while trying to connect to ~a, please retry.")
+           (G_ "An error occurred while trying to connect to ~a, please retry.")
            service-name)
    (G_ "Connection error")))
 
@@ -160,8 +160,8 @@ of <service-item> records present in LISTBOX."
 ;; Maximum length of a wifi service name.
 (define service-name-max-length (make-parameter 20))
 
-;; Heigth of the listbox displaying wifi services.
-(define wifi-listbox-heigth (make-parameter 20))
+;; Height of the listbox displaying wifi services.
+(define wifi-listbox-height (make-parameter 20))
 
 ;; Information textbox width.
 (define info-textbox-width (make-parameter 40))
@@ -188,7 +188,7 @@ network when the corresponding listbox entry is selected. A button allow to
 force a wifi scan."
   (let* ((listbox (make-listbox
                    -1 -1
-                   (wifi-listbox-heigth)
+                   (wifi-listbox-height)
                    (logior FLAG-SCROLL FLAG-BORDER FLAG-RETURNEXIT)))
          (form (make-form))
          (buttons-grid (make-grid 1 1))
-- 
2.20.1